var languageNames = {
"en-US": "Ingelesa (AEB)",
"sq": "Albaniera",
"am": "Amharera",
"ar": "Arabiera",
"ast": "Asturiera",
"bn": "Bengaliera",
"bn-IN": "Bengaliera (India)",
"bs": "Bosniera",
"bg": "Bulgariera",
"ca": "Katalana",
"ca-valencia": "Katalana (Valentzia)",
"zh-CN": "Txinera (soildua)",
"zh-TW": "Txinera (tradizionala)",
"hr": "Kroaziera",
"cs": "Txekiera",
"da": "Daniera",
"nl": "Nederlandera",
"dz": "Dzongkha",
"en-GB": "Ingelesa (EB)",
"en-ZA": "Ingelesa (HA)",
"eo": "Esperantoa",
"et": "Estoniera",
"eu": "Euskara",
"fi": "Finlandiera",
"fr": "Frantsesa",
"gl": "Galiziera",
"ka": "Georgiera",
"de": "Alemana",
"el": "Greziera",
"gu": "Gujaratera",
"he": "Hebreera",
"hi": "Hindia",
"hu": "Hungariera",
"id": "Indonesiera",
"is": "Islandiera",
"it": "Italiera",
"ja": "Japoniera",
"km": "Khmerera",
"ko": "Koreera",
"lo": "Laosera",
"lv": "Letoniera",
"lt": "Lituaniera",
"mk": "Mazedoniera",
"ne": "Nepalera",
"nn": "Norvegiera (Nynorsk)",
"nb": "Norvegiera (Bokmål)",
"om": "Oromoera",
"pl": "Poloniera",
"pt": "Portugesa",
"pt-BR": "Portugesa (Brasil)",
"ro": "Errumaniera",
"ru": "Errusiera",
"sid": "Sidamoa",
"si": "Sinhalera",
"sk": "Eslovakiera",
"sl": "Esloveniera",
"dsb": "Sorabiera (behekoa)",
"hsb": "Sorabiera (goikoa)",
"es": "Gaztelania",
"sv": "Suediera",
"tg": "Tajikera",
"ta": "Tamilera",
"bo": "Tibetera",
"tr": "Turkiera",
"ug": "Uigurrera",
"uk": "Ukrainiera",
"vi": "Vietnamera",
};
